import {
  loader_default
} from "./chunk-IRS4QQ7I.js";

// src/search.js
import React, { useCallback, useEffect, useRef } from "react";
import { Controller, FormProvider, useForm, useFormContext } from "react-hook-form";
import { Search as SearchIcon } from "@mui/icons-material";
import { InputAdornment, TextField } from "@mui/material";
import { makeStyles } from "tss-react/mui";
import { TIMEOUTS } from "@northern.tech/store/constants";
import { useDebounce } from "@northern.tech/utils/debouncehook";
import { jsx, jsxs } from "react/jsx-runtime";
var useStyles = makeStyles()(() => ({
  root: {
    input: {
      fontSize: "13px"
    }
  }
}));
var endAdornment = /* @__PURE__ */ jsx(InputAdornment, { position: "end", children: /* @__PURE__ */ jsx(loader_default, { show: true, small: true, style: { marginTop: -10 } }) });
var startAdornment = /* @__PURE__ */ jsx(InputAdornment, { position: "start", children: /* @__PURE__ */ jsx(SearchIcon, { color: "disabled", fontSize: "small" }) });
var MINIMUM_SEARCH_LENGTH = 2;
var ControlledSearch = ({ isSearching, name = "search", onSearch, placeholder = "Search devices", style = {} }) => {
  const { classes } = useStyles();
  const { control, watch } = useFormContext();
  const inputRef = useRef();
  const focusLockRef = useRef(true);
  const timer = useRef();
  const triggerDebounceRef = useRef(false);
  const searchValue = watch("search", "");
  const debouncedSearchTerm = useDebounce(searchValue, TIMEOUTS.debounceDefault);
  const focusAndLock = () => {
    focusLockRef.current = false;
    inputRef.current.focus();
    clearTimeout(timer.current);
    triggerDebounceRef.current = false;
    timer.current = setTimeout(() => focusLockRef.current = true, TIMEOUTS.oneSecond);
  };
  useEffect(() => {
    return () => {
      clearTimeout(timer.current);
    };
  }, []);
  useEffect(() => {
    if (debouncedSearchTerm.length < MINIMUM_SEARCH_LENGTH || triggerDebounceRef.current) {
      return;
    }
    triggerDebounceRef.current = true;
    onSearch(debouncedSearchTerm).then(focusAndLock);
  }, [debouncedSearchTerm, onSearch]);
  const onTriggerSearch = useCallback(
    ({ key }) => {
      if (key === "Enter" && (!debouncedSearchTerm || debouncedSearchTerm.length >= MINIMUM_SEARCH_LENGTH)) {
        onSearch(debouncedSearchTerm).then(focusAndLock);
      }
    },
    [debouncedSearchTerm, onSearch]
  );
  const onFocus = useCallback(() => {
    if (focusLockRef.current && debouncedSearchTerm.length >= MINIMUM_SEARCH_LENGTH) {
      onSearch(debouncedSearchTerm).then(focusAndLock);
    }
  }, [debouncedSearchTerm, onSearch]);
  const adornments = isSearching ? { startAdornment, endAdornment } : { startAdornment };
  return /* @__PURE__ */ jsx(
    Controller,
    {
      name,
      control,
      render: ({ field }) => /* @__PURE__ */ jsx(
        TextField,
        {
          className: classes.root,
          InputProps: adornments,
          onKeyUp: onTriggerSearch,
          onFocus,
          placeholder,
          inputRef,
          size: "small",
          style,
          ...field
        }
      )
    }
  );
};
ControlledSearch.displayName = "ConnectedSearch";
var Search = (props) => {
  const { searchTerm, onSearch, trigger } = props;
  const methods = useForm({ mode: "onChange", defaultValues: { search: searchTerm ?? "" } });
  const { handleSubmit } = methods;
  const onSubmit = useCallback((search) => onSearch(search, !trigger), [onSearch, trigger]);
  return /* @__PURE__ */ jsx(FormProvider, { ...methods, children: /* @__PURE__ */ jsxs("form", { noValidate: true, onSubmit: handleSubmit(({ search }) => onSearch(search, !trigger)), children: [
    /* @__PURE__ */ jsx(ControlledSearch, { ...props, onSearch: onSubmit }),
    /* @__PURE__ */ jsx("input", { className: "hidden", type: "submit" })
  ] }) });
};
var search_default = Search;

export {
  ControlledSearch,
  search_default
};
//# sourceMappingURL=chunk-A3YVRM5B.js.map