declare const useradmApiUrlv1: string;
declare const useradmApiUrlv2: string;

type UiPermission = {
    explanations: object;
    permissionSets: Record<string, string>;
    permissionLevel: number;
    title: string;
    value: string;
    verbs: string[];
};
type ExcessiveAccessConfig = {
    selector: string;
    warning: string;
};
type EndpointDefinition = {
    path: RegExp;
    types: string[];
    uiPermissions: UiPermission[];
};
type PermissionsArea = {
    endpoints: EndpointDefinition[];
    explanation: string;
    uiPermissions: UiPermission[];
    title: string;
    key: string;
    scope?: string;
    filter?: (object: any) => string[];
    placeholder?: string;
    excessiveAccessConfig?: ExcessiveAccessConfig;
};
declare const PermissionTypes: {
    Any: string;
    Get: string;
    Post: string;
    Put: string;
    Delete: string;
    Patch: string;
    DeviceGroup: string;
    DeviceId: string;
};
declare const uiPermissionsById: {
    configure: {
        explanations: {
            groups: string;
        };
        permissionLevel: number;
        permissionSets: {
            groups: string;
        };
        title: string;
        value: string;
        verbs: string[];
    };
    connect: {
        explanations: {
            groups: string;
        };
        permissionLevel: number;
        permissionSets: {
            groups: string;
        };
        title: string;
        value: string;
        verbs: string[];
    };
    deploy: {
        explanations: {
            groups: string;
        };
        permissionLevel: number;
        permissionSets: {
            deployments: string;
            groups: string;
        };
        title: string;
        value: string;
        verbs: string[];
    };
    manage: {
        explanations: {
            groups: string;
            releases: string;
        };
        permissionLevel: number;
        permissionSets: {
            groups: string;
            releases: string;
            tenantManagement: string;
            userManagement: string;
        };
        title: string;
        value: string;
        verbs: string[];
    };
    read: {
        explanations: {
            groups: string;
        };
        permissionLevel: number;
        permissionSets: {
            auditlog: string;
            groups: string;
            releases: string;
            tenantManagement: string;
            userManagement: string;
        };
        title: string;
        value: string;
        verbs: string[];
    };
    upload: {
        explanations: {
            groups: string;
        };
        unscopedOnly: {
            releases: boolean;
        };
        permissionLevel: number;
        permissionSets: {
            releases: string;
        };
        title: string;
        value: string;
        verbs: string[];
    };
};
/**
 * _uiPermissions_ represent the possible permissions/ rights that can be given for the area
 * _endpoints_ represent the possible endpoints this definition might be affecting in the UI and what
 *              functionality might be affected
 *
 */
declare const scopedPermissionAreas: {
    groups: {
        key: string;
        excessiveAccessSelector: string;
        scopeType: string;
    };
    releases: {
        key: string;
        excessiveAccessSelector: string;
        scopeType: string;
    };
};
declare const uiPermissionsByArea: {
    auditlog: {
        endpoints: {
            path: RegExp;
            types: string[];
            uiPermissions: {
                explanations: {
                    groups: string;
                };
                permissionLevel: number;
                permissionSets: {
                    auditlog: string;
                    groups: string;
                    releases: string;
                    tenantManagement: string;
                    userManagement: string;
                };
                title: string;
                value: string;
                verbs: string[];
            }[];
        }[];
        explanation: string;
        key: string;
        uiPermissions: {
            explanations: {
                groups: string;
            };
            permissionLevel: number;
            permissionSets: {
                auditlog: string;
                groups: string;
                releases: string;
                tenantManagement: string;
                userManagement: string;
            };
            title: string;
            value: string;
            verbs: string[];
        }[];
        title: string;
    };
    deployments: {
        endpoints: ({
            path: RegExp;
            types: string[];
            uiPermissions: {
                explanations: {
                    groups: string;
                };
                permissionLevel: number;
                permissionSets: {
                    deployments: string;
                    groups: string;
                };
                title: string;
                value: string;
                verbs: string[];
            }[];
        } | {
            path: RegExp;
            types: string[];
            uiPermissions: {
                explanations: {
                    groups: string;
                };
                permissionLevel: number;
                permissionSets: {
                    auditlog: string;
                    groups: string;
                    releases: string;
                    tenantManagement: string;
                    userManagement: string;
                };
                title: string;
                value: string;
                verbs: string[];
            }[];
        } | {
            path: RegExp;
            types: string[];
            uiPermissions: {
                explanations: {
                    groups: string;
                    releases: string;
                };
                permissionLevel: number;
                permissionSets: {
                    groups: string;
                    releases: string;
                    tenantManagement: string;
                    userManagement: string;
                };
                title: string;
                value: string;
                verbs: string[];
            }[];
        })[];
        explanation: string;
        key: string;
        uiPermissions: ({
            explanations: {
                groups: string;
            };
            permissionLevel: number;
            permissionSets: {
                deployments: string;
                groups: string;
            };
            title: string;
            value: string;
            verbs: string[];
        } | {
            explanations: {
                groups: string;
            };
            permissionLevel: number;
            permissionSets: {
                auditlog: string;
                groups: string;
                releases: string;
                tenantManagement: string;
                userManagement: string;
            };
            title: string;
            value: string;
            verbs: string[];
        })[];
        title: string;
    };
    groups: {
        endpoints: {
            path: RegExp;
            types: string[];
            uiPermissions: {
                explanations: {
                    groups: string;
                };
                permissionLevel: number;
                permissionSets: {
                    groups: string;
                };
                title: string;
                value: string;
                verbs: string[];
            }[];
        }[];
        explanation: string;
        key: string;
        scope: string;
        uiPermissions: {
            explanations: {
                groups: string;
            };
            permissionLevel: number;
            permissionSets: {
                groups: string;
            };
            title: string;
            value: string;
            verbs: string[];
        }[];
        title: string;
    };
    releases: {
        endpoints: ({
            path: RegExp;
            types: string[];
            uiPermissions: ({
                explanations: {
                    groups: string;
                };
                permissionLevel: number;
                permissionSets: {
                    auditlog: string;
                    groups: string;
                    releases: string;
                    tenantManagement: string;
                    userManagement: string;
                };
                title: string;
                value: string;
                verbs: string[];
            } | {
                explanations: {
                    groups: string;
                };
                unscopedOnly: {
                    releases: boolean;
                };
                permissionLevel: number;
                permissionSets: {
                    releases: string;
                };
                title: string;
                value: string;
                verbs: string[];
            })[];
        } | {
            path: RegExp;
            types: string[];
            uiPermissions: ({
                explanations: {
                    groups: string;
                    releases: string;
                };
                permissionLevel: number;
                permissionSets: {
                    groups: string;
                    releases: string;
                    tenantManagement: string;
                    userManagement: string;
                };
                title: string;
                value: string;
                verbs: string[];
            } | {
                explanations: {
                    groups: string;
                };
                permissionLevel: number;
                permissionSets: {
                    auditlog: string;
                    groups: string;
                    releases: string;
                    tenantManagement: string;
                    userManagement: string;
                };
                title: string;
                value: string;
                verbs: string[];
            })[];
        })[];
        explanation: string;
        key: string;
        scope: string;
        uiPermissions: ({
            explanations: {
                groups: string;
                releases: string;
            };
            permissionLevel: number;
            permissionSets: {
                groups: string;
                releases: string;
                tenantManagement: string;
                userManagement: string;
            };
            title: string;
            value: string;
            verbs: string[];
        } | {
            explanations: {
                groups: string;
            };
            permissionLevel: number;
            permissionSets: {
                auditlog: string;
                groups: string;
                releases: string;
                tenantManagement: string;
                userManagement: string;
            };
            title: string;
            value: string;
            verbs: string[];
        } | {
            explanations: {
                groups: string;
            };
            unscopedOnly: {
                releases: boolean;
            };
            permissionLevel: number;
            permissionSets: {
                releases: string;
            };
            title: string;
            value: string;
            verbs: string[];
        })[];
        title: string;
    };
    tenantManagement: {
        endpoints: ({
            path: RegExp;
            types: string[];
            uiPermissions: {
                explanations: {
                    groups: string;
                };
                permissionLevel: number;
                permissionSets: {
                    auditlog: string;
                    groups: string;
                    releases: string;
                    tenantManagement: string;
                    userManagement: string;
                };
                title: string;
                value: string;
                verbs: string[];
            }[];
        } | {
            path: RegExp;
            types: string[];
            uiPermissions: {
                explanations: {
                    groups: string;
                    releases: string;
                };
                permissionLevel: number;
                permissionSets: {
                    groups: string;
                    releases: string;
                    tenantManagement: string;
                    userManagement: string;
                };
                title: string;
                value: string;
                verbs: string[];
            }[];
        })[];
        explanation: string;
        key: string;
        uiPermissions: ({
            explanations: {
                groups: string;
                releases: string;
            };
            permissionLevel: number;
            permissionSets: {
                groups: string;
                releases: string;
                tenantManagement: string;
                userManagement: string;
            };
            title: string;
            value: string;
            verbs: string[];
        } | {
            explanations: {
                groups: string;
            };
            permissionLevel: number;
            permissionSets: {
                auditlog: string;
                groups: string;
                releases: string;
                tenantManagement: string;
                userManagement: string;
            };
            title: string;
            value: string;
            verbs: string[];
        })[];
        title: string;
    };
    userManagement: {
        endpoints: ({
            path: RegExp;
            types: string[];
            uiPermissions: {
                explanations: {
                    groups: string;
                };
                permissionLevel: number;
                permissionSets: {
                    auditlog: string;
                    groups: string;
                    releases: string;
                    tenantManagement: string;
                    userManagement: string;
                };
                title: string;
                value: string;
                verbs: string[];
            }[];
        } | {
            path: RegExp;
            types: string[];
            uiPermissions: {
                explanations: {
                    groups: string;
                    releases: string;
                };
                permissionLevel: number;
                permissionSets: {
                    groups: string;
                    releases: string;
                    tenantManagement: string;
                    userManagement: string;
                };
                title: string;
                value: string;
                verbs: string[];
            }[];
        })[];
        explanation: string;
        key: string;
        uiPermissions: ({
            explanations: {
                groups: string;
                releases: string;
            };
            permissionLevel: number;
            permissionSets: {
                groups: string;
                releases: string;
                tenantManagement: string;
                userManagement: string;
            };
            title: string;
            value: string;
            verbs: string[];
        } | {
            explanations: {
                groups: string;
            };
            permissionLevel: number;
            permissionSets: {
                auditlog: string;
                groups: string;
                releases: string;
                tenantManagement: string;
                userManagement: string;
            };
            title: string;
            value: string;
            verbs: string[];
        })[];
        title: string;
    };
};
declare const itemUiPermissionsReducer: (accu: any, { item, uiPermissions }: {
    item: any;
    uiPermissions: any;
}) => any;
declare const checkPermissionsObject: (permissions: any, requiredPermission: any, scopedAccess: any, superAccess: any) => any;
declare const rolesById: Readonly<{
    [x: string]: {
        name: string;
        value: string;
        description: string;
        permissions: never[];
        uiPermissions: {
            auditlog: any[];
            deployments: any[];
            groups: {
                "All devices": any[];
            };
            releases: {
                "All releases": any[];
            };
            userManagement: any[];
            tenantManagement: string[];
        };
    } | {
        name: string;
        value: string;
        description: string;
        permissions: never[];
        uiPermissions: {
            releases: {
                "All releases": any[];
            };
            auditlog: string[];
            deployments?: string[];
            groups: Record<string, string[]>;
            tenantManagement: string[];
            userManagement: string[];
        };
    } | {
        name: string;
        value: string;
        description: string;
        permissions: never[];
        uiPermissions: {
            groups: {
                "All devices": string[];
            };
            auditlog: string[];
            deployments?: string[];
            releases: Record<string, string[]>;
            tenantManagement: string[];
            userManagement: string[];
        };
    };
}>;
declare const serviceProviderRolesById: {
    admin: {
        name: string;
        value: string;
        description: string;
        permissions: never[];
        uiPermissions: {
            auditlog: any[];
            userManagement: any[];
            tenantManagement: any[];
            deployments?: string[];
            groups: Record<string, string[]>;
            releases: Record<string, string[]>;
        };
    };
    readOnly: {
        name: string;
        value: string;
        description: string;
        permissions: never[];
        uiPermissions: {
            auditlog: string[];
            userManagement: string[];
            tenantManagement: string[];
            deployments?: string[];
            groups: Record<string, string[]>;
            releases: Record<string, string[]>;
        };
    };
};
declare const defaultPermissionSets: {
    [x: string]: {
        name: string;
        result: {
            userManagement: string[];
            auditlog?: undefined;
            releases?: undefined;
            tenantManagement?: undefined;
            deployments?: undefined;
            groups?: undefined;
        };
    } | {
        name: string;
        result: {
            auditlog: any[];
            deployments: any[];
            groups: {
                "All devices": any[];
            };
            releases: {
                "All releases": any[];
            };
            userManagement: any[];
            tenantManagement: string[];
        } | {
            releases: {
                "All releases": any[];
            };
            auditlog: string[];
            deployments?: string[];
            groups: Record<string, string[]>;
            tenantManagement: string[];
            userManagement: string[];
        } | {
            groups: {
                "All devices": string[];
            };
            auditlog: string[];
            deployments?: string[];
            releases: Record<string, string[]>;
            tenantManagement: string[];
            userManagement: string[];
        };
    } | {
        name: string;
        result: {
            auditlog: string[];
            userManagement?: undefined;
            releases?: undefined;
            tenantManagement?: undefined;
            deployments?: undefined;
            groups?: undefined;
        };
    } | {
        name: string;
        result: {
            releases: {
                "All releases": string[];
            };
            userManagement?: undefined;
            auditlog?: undefined;
            tenantManagement?: undefined;
            deployments?: undefined;
            groups?: undefined;
        };
    } | {
        name: string;
        result: {
            tenantManagement: string[];
            userManagement?: undefined;
            auditlog?: undefined;
            releases?: undefined;
            deployments?: undefined;
            groups?: undefined;
        };
    } | {
        name: string;
        result: {
            deployments: string[];
            groups: {
                "All devices": string[];
            };
            userManagement?: undefined;
            auditlog?: undefined;
            releases?: undefined;
            tenantManagement?: undefined;
        };
    } | {
        name: string;
        result: {
            groups: {
                "All devices": string[];
            };
            userManagement?: undefined;
            auditlog?: undefined;
            releases?: undefined;
            tenantManagement?: undefined;
            deployments?: undefined;
        };
    };
};
declare const USER_LOGOUT = "USER_LOGOUT";
declare const OWN_USER_ID = "me";
declare const rolesByName: {
    deploymentCreation: {
        action: string;
        object: {
            type: string;
            value: undefined;
        };
    };
    groupAccess: {
        action: string;
        object: {
            type: string;
            value: undefined;
        };
    };
    userManagement: {
        action: string;
        object: {
            type: string;
            value: string;
        };
    };
    admin: string;
    readOnly: string;
    ci: string;
    deploymentsManager: string;
    terminalAccess: string;
};
declare const twoFAStates: {
    enabled: string;
    disabled: string;
    unverified: string;
};
declare const settingsKeys: {
    initialized: string;
};
declare const READ_STATES: {
    read: string;
    seen: string;
    unread: string;
};

export { OWN_USER_ID, PermissionTypes, type PermissionsArea, READ_STATES, USER_LOGOUT, type UiPermission, checkPermissionsObject, defaultPermissionSets, itemUiPermissionsReducer, rolesById, rolesByName, scopedPermissionAreas, serviceProviderRolesById, settingsKeys, twoFAStates, uiPermissionsByArea, uiPermissionsById, useradmApiUrlv1 as useradmApiUrl, useradmApiUrlv1, useradmApiUrlv2 };
